@@ -194,8 +194,8 @@ void ConnectionEditor::connectClicked()
     return;
   MetaDataBase::Connection conn;
   conn.sender = m_sender;
-  conn.signal = signalBox->currentText();
-  conn.slot = slotBox->currentText();
+  conn.signal = signalBox->currentText().utf8();
+  conn.slot = slotBox->currentText().utf8();
   conn.receiver = m_receiver;
   TDEListViewItem *i = new TDEListViewItem(connectionView, m_sender->name(), conn.signal, m_receiver->name(),
                                        conn.slot);                       
